Skip to contents

Creates a data frame with the residuals of partial regressions of the main explanatory variable and the variable of interest. This method follows the Frisch-Waugh-Lovell theorem, as explained in Lovell (2008) doi:10.3200/JECE.39.1.88-91 .

Author

Maintainer: Marc Bosch-Matas mboschmatas@gmail.com (ORCID)

Other contributors:

  • Christian Testa (Christian reviewed the package (v. 0.1.1) for rOpenSci, see <https://github.com/ropensci/software-review/issues/703>) [reviewer]

  • Kyle Butts (Kyle reviewed the package (v. 0.1.1) for rOpenSci, see <https://github.com/ropensci/software-review/issues/703>) [reviewer]

  • Adam Loy (Adam reviewed the package (v. 0.1.1) for rOpenSci, see <https://github.com/ropensci/software-review/issues/703>) [reviewer]